@@ -22,6 +22,7 @@
 # include "config.h"
 #endif
 
+#include "gstasfelements.h"
 #include "gstrtpasfdepay.h"
 #include <gst/rtp/gstrtpbuffer.h>
 
@@ -53,6 +54,8 @@ static GstStaticPadTemplate sink_factory = GST_STATIC_PAD_TEMPLATE ("sink",
 
 #define gst_rtp_asf_depay_parent_class parent_class
 G_DEFINE_TYPE (GstRtpAsfDepay, gst_rtp_asf_depay, GST_TYPE_RTP_BASE_DEPAYLOAD);
+GST_ELEMENT_REGISTER_DEFINE_WITH_CODE (rtpasfdepay, "rtpasfdepay",
+    GST_RANK_MARGINAL, GST_TYPE_RTP_ASF_DEPAY, asf_element_init (plugin));
 
 static void gst_rtp_asf_depay_finalize (GObject * object);
 
@@ -101,6 +104,9 @@ gst_rtp_asf_depay_class_init (GstRtpAsfDepayClass * klass)
 static void
 gst_rtp_asf_depay_init (GstRtpAsfDepay * depay)
 {
+  gst_rtp_base_depayload_set_aggregate_hdrext_enabled (GST_RTP_BASE_DEPAYLOAD
+      (depay), TRUE);
+
   depay->adapter = gst_adapter_new ();
 }
 
@@ -332,6 +338,7 @@ gst_rtp_asf_depay_process (GstRTPBaseDepayload * depayload, GstBuffer * buf)
   GstRtpAsfDepay *depay;
   const guint8 *payload;
   GstBuffer *outbuf;
+  GstBufferList *outbufs = NULL;
   gboolean S, L, R, D, I;
   guint payload_len, hdr_len, offset;
   guint len_offs;
@@ -356,6 +363,7 @@ gst_rtp_asf_depay_process (GstRTPBaseDepayload * depayload, GstBuffer * buf)
 
   GST_LOG_OBJECT (depay, "got payload len of %u", payload_len);
 
+  outbufs = gst_buffer_list_new ();
   do {
     guint packet_len;
 
@@ -470,9 +478,12 @@ gst_rtp_asf_depay_process (GstRTPBaseDepayload * depayload, GstBuffer * buf)
           gst_rtp_buffer_get_payload_subbuffer (&rtpbuf, offset, packet_len);
     }
 
-    /* If we haven't completed a full ASF packet, return */
-    if (!outbuf)
+    /* If we haven't completed a full ASF packet, return but first
+       push what we have so far */
+    if (!outbuf) {
+      gst_rtp_base_depayload_push_list (depayload, outbufs);
       return NULL;
+    }
 
     outbuf = gst_rtp_asf_depay_update_padding (depay, outbuf);
 
@@ -487,7 +498,7 @@ gst_rtp_asf_depay_process (GstRTPBaseDepayload * depayload, GstBuffer * buf)
 
     GST_BUFFER_TIMESTAMP (outbuf) = timestamp;
 
-    gst_rtp_base_depayload_push (depayload, outbuf);
+    gst_buffer_list_add (outbufs, outbuf);
 
     /* only apply the timestamp to the first buffer of this packet */
     timestamp = -1;
@@ -498,6 +509,8 @@ gst_rtp_asf_depay_process (GstRTPBaseDepayload * depayload, GstBuffer * buf)
     payload_len -= packet_len;
   } while (payload_len > 0);
 
+  gst_rtp_base_depayload_push_list (depayload, outbufs);
+
   gst_rtp_buffer_unmap (&rtpbuf);
 
   return NULL;
@@ -508,6 +521,12 @@ too_small:
     gst_rtp_buffer_unmap (&rtpbuf);
     GST_WARNING_OBJECT (depayload, "Payload too small, expected at least 4 "
         "bytes for header, but got only %d bytes", payload_len);
+    if (gst_buffer_list_length (outbufs) == 0) {
+      gst_rtp_base_depayload_dropped (depayload);
+      gst_buffer_list_unref (outbufs);
+    } else {
+      gst_rtp_base_depayload_push_list (depayload, outbufs);
+    }
     return NULL;
   }
 }
